==> haskell-nettle-0.3.0-45-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-nettle.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: nettle
version: 0.3.0
id: nettle-0.3.0-6HA1YEeaJQ9Gydht9Aw68k
key: nettle-0.3.0-6HA1YEeaJQ9Gydht9Aw68k
license: MIT
copyright: Stefan Bühler <stbuehler@web.de>
maintainer: Stefan Bühler <stbuehler@web.de>
author: Stefan Bühler <stbuehler@web.de>
homepage: https://github.com/stbuehler/haskell-nettle
synopsis: safe nettle binding
description:
    safe binding for the nettle (<http://www.lysator.liu.se/~nisse/nettle/nettle.html>) library.
    Tested with 3.4, might work with 3.2 (but not earlier).
category: Cryptography
abi: 703ebfa2f3ea57327f7193c154e265ed
exposed: True
exposed-modules:
    Crypto.Nettle.CCM Crypto.Nettle.ChaChaPoly1305
    Crypto.Nettle.Ciphers Crypto.Nettle.HMAC Crypto.Nettle.Hash
    Crypto.Nettle.KeyedHash Crypto.Nettle.UMAC
hidden-modules: Crypto.Nettle.Ciphers.Internal
                Crypto.Nettle.Ciphers.ForeignImports
                Crypto.Nettle.Hash.ForeignImports Crypto.Nettle.Hash.Types
                Nettle.Utils
import-dirs: /usr/lib/ghc-8.6.5/site-local/nettle-0.3.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/nettle-0.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/nettle-0.3.0
hs-libraries: HSnettle-0.3.0-6HA1YEeaJQ9Gydht9Aw68k
extra-libraries:
    nettle
depends:
    base-4.12.0.0 byteable-0.1.1-9guyEXUUK503mzSnI32g2S
    bytestring-0.10.8.2
    crypto-cipher-types-0.0.9-17KnAsArwMDKS50OczHA7y
    securemem-0.1.10-AgRbjRbsMHcJeKnVmNGCBY
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP
haddock-interfaces: /usr/share/doc/haskell-nettle/html/nettle.haddock
haddock-html: /usr/share/doc/haskell-nettle/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-nettle-0.3.0-49-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-nettle.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: nettle
version: 0.3.0
id: nettle-0.3.0-HoFavxnE2SW6Q99lQDyFQR
key: nettle-0.3.0-HoFavxnE2SW6Q99lQDyFQR
license: MIT
copyright: Stefan Bühler <stbuehler@web.de>
maintainer: Stefan Bühler <stbuehler@web.de>
author: Stefan Bühler <stbuehler@web.de>
homepage: https://github.com/stbuehler/haskell-nettle
synopsis: safe nettle binding
description:
    safe binding for the nettle (<http://www.lysator.liu.se/~nisse/nettle/nettle.html>) library.
    Tested with 3.4, might work with 3.2 (but not earlier).
category: Cryptography
abi: ad8a3f454aeee025b138241dbc31330a
exposed: True
exposed-modules:
    Crypto.Nettle.CCM Crypto.Nettle.ChaChaPoly1305
    Crypto.Nettle.Ciphers Crypto.Nettle.HMAC Crypto.Nettle.Hash
    Crypto.Nettle.KeyedHash Crypto.Nettle.UMAC
hidden-modules: Crypto.Nettle.Ciphers.Internal
                Crypto.Nettle.Ciphers.ForeignImports
                Crypto.Nettle.Hash.ForeignImports Crypto.Nettle.Hash.Types
                Nettle.Utils
import-dirs: /usr/lib/ghc-8.6.5/site-local/nettle-0.3.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/nettle-0.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/nettle-0.3.0
hs-libraries: HSnettle-0.3.0-HoFavxnE2SW6Q99lQDyFQR
extra-libraries:
    nettle
depends:
    base-4.12.0.0 byteable-0.1.1-9guyEXUUK503mzSnI32g2S
    bytestring-0.10.8.2 crypto-cipher-types-0.0.9-DXpvZNJsGutNPf1lCSHHK
    securemem-0.1.10-L4TfLmHXcEx8teV0rzp6zE
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP
haddock-interfaces: /usr/share/doc/haskell-nettle/html/nettle.haddock
haddock-html: /usr/share/doc/haskell-nettle/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
